==> seedsui-react-5.5.91.tgz: package/lib/Player/Player.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

var _excluded = ["portal", "src", "maskAttribute", "videoAttribute", "poster", "children"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import PlayerDialog from "./PlayerDialog";
import Context from "../Context/instance.js";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var Player = /*#__PURE__*/function (_Component) {
  _inherits(Player, _Component);

  var _super = _createSuper(Player);

  function Player() {
    var _this;

    _classCallCheck(this, Player);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _super.call.apply(_super, [this].concat(args));

    _defineProperty(_assertThisInitialized(_this), "state", {
      videoShow: false
    });

    _defineProperty(_assertThisInitialized(_this), "play", function (e, show) {
      _this.setState({
        videoShow: show
      });

      e.stopPropagation();
    });

    return _this;
  }

  _createClass(Player, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.$ComponentPlayerDialog = this.refs.$ComponentPlayerDialog;
      this.$video = this.refs.$ComponentPlayerDialog.$el;
    } // 显隐视频弹窗

  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          portal = _this$props.portal,
          src = _this$props.src,
          _this$props$maskAttri = _this$props.maskAttribute,
          maskAttribute = _this$props$maskAttri === void 0 ? {} : _this$props$maskAttri,
          _this$props$videoAttr = _this$props.videoAttribute,
          videoAttribute = _this$props$videoAttr === void 0 ? {} : _this$props$videoAttr,
          poster = _this$props.poster,
          children = _this$props.children,
          others = _objectWithoutProperties(_this$props, _excluded);

      return /*#__PURE__*/_jsxs("div", _objectSpread(_objectSpread({
        ref: function ref(el) {
          _this2.$el = el;
        }
      }, others), {}, {
        className: 'player-thumbnail' + (others.className ? ' ' + others.className : ''),
        onClick: others.onClick ? others.onClick : function (e) {
          return _this2.play(e, true);
        },
        children: [poster && /*#__PURE__*/_jsx("div", {
          style: {
            backgroundImage: "url(".concat(poster, ")")
          },
          className: "player-thumbnail-poster"
        }), /*#__PURE__*/_jsx("div", {
          className: "player-thumbnail-button"
        }), children, /*#__PURE__*/_jsx(PlayerDialog, {
          ref: "$ComponentPlayerDialog",
          show: this.state.videoShow,
          portal: portal,
          src: src,
          maskAttribute: maskAttribute,
          videoAttribute: videoAttribute,
          onHide: function onHide(e) {
            return _this2.play(e, false);
          }
        })]
      }));
    }
  }]);

  return Player;
}(Component);

_defineProperty(Player, "contextType", Context);

_defineProperty(Player, "propTypes", {
  portal: PropTypes.object,
  src: PropTypes.string,
  maskAttribute: PropTypes.object,
  videoAttribute: PropTypes.object,
  poster: PropTypes.string,
  children: PropTypes.node
});

_defineProperty(Player, "defaultProps", {});

export { Player as default };

==> seedsui-react-5.5.92.tgz: package/lib/Player/Player.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

var _excluded = ["portal", "src", "maskAttribute", "videoAttribute", "poster", "children"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import PlayerDialog from "./PlayerDialog";
import Context from "../Context/instance.js";

var Player = /*#__PURE__*/function (_Component) {
  _inherits(Player, _Component);

  var _super = _createSuper(Player);

  function Player() {
    var _this;

    _classCallCheck(this, Player);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _super.call.apply(_super, [this].concat(args));

    _defineProperty(_assertThisInitialized(_this), "state", {
      videoShow: false
    });

    _defineProperty(_assertThisInitialized(_this), "play", function (e, show) {
      _this.setState({
        videoShow: show
      });

      e.stopPropagation();
    });

    return _this;
  }

  _createClass(Player, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.$ComponentPlayerDialog = this.refs.$ComponentPlayerDialog;
      this.$video = this.refs.$ComponentPlayerDialog.$el;
    } // 显隐视频弹窗

  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          portal = _this$props.portal,
          src = _this$props.src,
          _this$props$maskAttri = _this$props.maskAttribute,
          maskAttribute = _this$props$maskAttri === void 0 ? {} : _this$props$maskAttri,
          _this$props$videoAttr = _this$props.videoAttribute,
          videoAttribute = _this$props$videoAttr === void 0 ? {} : _this$props$videoAttr,
          poster = _this$props.poster,
          children = _this$props.children,
          others = _objectWithoutProperties(_this$props, _excluded);

      return /*#__PURE__*/React.createElement("div", _extends({
        ref: function ref(el) {
          _this2.$el = el;
        }
      }, others, {
        className: 'player-thumbnail' + (others.className ? ' ' + others.className : ''),
        onClick: others.onClick ? others.onClick : function (e) {
          return _this2.play(e, true);
        }
      }), poster && /*#__PURE__*/React.createElement("div", {
        style: {
          backgroundImage: "url(".concat(poster, ")")
        },
        className: "player-thumbnail-poster"
      }), /*#__PURE__*/React.createElement("div", {
        className: "player-thumbnail-button"
      }), children, /*#__PURE__*/React.createElement(PlayerDialog, {
        ref: "$ComponentPlayerDialog",
        show: this.state.videoShow,
        portal: portal,
        src: src,
        maskAttribute: maskAttribute,
        videoAttribute: videoAttribute,
        onHide: function onHide(e) {
          return _this2.play(e, false);
        }
      }));
    }
  }]);

  return Player;
}(Component);

_defineProperty(Player, "contextType", Context);

_defineProperty(Player, "propTypes", {
  portal: PropTypes.object,
  src: PropTypes.string,
  maskAttribute: PropTypes.object,
  videoAttribute: PropTypes.object,
  poster: PropTypes.string,
  children: PropTypes.node
});

_defineProperty(Player, "defaultProps", {});

export { Player as default };
